From 77059dd4b98f422c1e474b9ee53cc05dde875cce Mon Sep 17 00:00:00 2001
From: Mart Raudsepp <leio@gentoo.org>
Date: Wed, 13 Feb 2019 20:09:45 +0200
Subject: [PATCH 2/5] libtracker-common: improve test_path_evaluate_name
 environment handling

Under some environments $PWD might not point where we expect, so simply
use g_get_current_dir() instead.
g_getenv() is documented to return a pointer that may get overwritten
by subsequent calls to g_getenv, g_setenv of g_unsetenv. As even after
removing the second g_getenv, there's still g_setenv calls, take a copy.
---
 tests/libtracker-common/tracker-file-utils-test.c | 8 +++++---
 1 file changed, 5 insertions(+), 3 deletions(-)

diff --git a/tests/libtracker-common/tracker-file-utils-test.c b/tests/libtracker-common/tracker-file-utils-test.c
index d1ddf3004..71a82a5c8 100644
--- a/tests/libtracker-common/tracker-file-utils-test.c
+++ b/tests/libtracker-common/tracker-file-utils-test.c
@@ -131,14 +131,14 @@ test_path_list_filter_duplicates_with_exceptions ()
 static void
 test_path_evaluate_name (void)
 {
-	gchar *result, *expected;
+	gchar *result, *expected, *pwd, *home;
 
-	const gchar *home = g_getenv ("HOME");
-	const gchar *pwd = g_getenv ("PWD");
 
 	const gchar *test = "/one/two";
 	gchar *parent_dir;
 
+	home = g_strdup (g_getenv ("HOME"));
+	pwd = g_get_current_dir ();
 	g_setenv ("TEST_TRACKER_DIR", test, TRUE);
 
 
@@ -216,6 +216,8 @@ test_path_evaluate_name (void)
 	result = tracker_path_evaluate_name (tracker_test_helpers_get_nonutf8 ());
 	g_assert_cmpstr (result, ==, tracker_test_helpers_get_nonutf8 ());
 
+	g_free (home);
+	g_free (pwd);
 	g_unsetenv ("TEST_TRACKER_DIR");
 }
 
-- 
2.17.0

